@@ -13,7 +13,7 @@ use Data::Dumper qw/Dumper/;
 use English qw/ -no_match_vars /;
 use Net::GitHub;
 
-our $VERSION     = version->new('0.0.2');
+our $VERSION     = version->new('0.0.3');
 our @EXPORT_OK   = qw//;
 our %EXPORT_TAGS = ();
 #our @EXPORT      = qw//;
@@ -29,7 +29,7 @@ has github => (
 
 sub _repos {
     my ($self) = @_;
-    my %repos;
+    my %repos = %{ $self->SUPER::_repos() };
 
     for my $repo ( $self->github->repos->list ) {
         $repos{ $repo->{name} } = Group::Git::Repo->new(
@@ -61,7 +61,7 @@ Group::Git::Github - Adds reading all repositories you have access to on github
 
 =head1 VERSION
 
-This documentation refers to Group::Git::Github version 0.0.2.
+This documentation refers to Group::Git::Github version 0.0.3.
 
 
 =head1 SYNOPSIS
